/*
 * Canvas.java
 *
 * Created on November 7, 2007, 1:12 PM
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */
package org.biolegato.core.plugintypes;

import org.biolegato.core.data.sequence.Sequence;
import javax.swing.Box;
import javax.swing.event.ChangeListener;
import org.biolegato.core.main.BLMain;

/**
 * All subclasses are expected to implement a displayable canvas for BioLegato.
 * 
 * @author Graham Alvare
 * @author Brian Fristensky
 */
public abstract class DataCanvas extends Box implements ChangeListener {
	/**
	 * Creates a new instance of BLCanvas
	 * 
	 * @param alignment the alignment for the box.
	 */
	protected DataCanvas (int alignment) {
		super(alignment);
	}

	/**
	 * Returns the current/selected data in the canvas.
	 *
	 * @return the current data for usage by commands
	 */
	public Sequence[] getData () {
		return getAllData();
	}

	/**
	 * Returns the complete contents of the data in the canvas.
	 *
	 * @return the complete contents of the data in the canvas
	 */
	public final Sequence[] getAllData () {
		Sequence[] result = new Sequence[BLMain.getSeqDoc().getLineCount()];
		for (int line = 0; line < BLMain.getSeqDoc().getLineCount(); line++) {
			result[line] = BLMain.getSeqDoc().getLine(line);
		}
		return result;
	}

	/**
	 * Returns the name of the canvas.
	 *
	 * @return the name to display for the canvas in all program text referring to it.
	 */
	public abstract String getTabName ();

	/**
	 * Refreshes the canvas on tab changes.
	 * Override this method, if you wish to do anything special on tab changes.
	 *
	 * @param event used to determine whether or not to refresh/
	 */
	public void stateChanged (javax.swing.event.ChangeEvent event) {
	}
}
